@@ -33,15 +33,17 @@ class ArticleItem(scrapy.Item):
     download_image = scrapy.Field()
     created_date = scrapy.Field()
     crawl_comment = scrapy.Field()
+    comment_total_count = scrapy.Field()
+    err_msg = scrapy.Field()
+
 
 class ArticleCommentItem(scrapy.Item):
     task_id = scrapy.Field()
     domain_url = scrapy.Field()
     domain_id = scrapy.Field()
     domain_name = scrapy.Field()
-    source_url = scrapy.Field()
-    source_id = scrapy.Field()
-    source_name = scrapy.Field()
+    post_url = scrapy.Field()
+    post_id = scrapy.Field()
     block_id = scrapy.Field()
     comment_id = scrapy.Field()
     url = scrapy.Field()
@@ -55,6 +57,7 @@ class ArticleCommentItem(scrapy.Item):
     publish_date = scrapy.Field()
     created_date = scrapy.Field()
 
+
 def get_item(response, source, block, parse=True, uploadOss=True, crawlComment=False):
     item = ArticleItem()
     item["domain_url"] = block["domain_url"]
@@ -80,27 +83,21 @@ def get_item(response, source, block, parse=True, uploadOss=True, crawlComment=F
             auto_parse(item, response)
     return item
 
-def get_comment_item(response, source, block, parse=True, uploadOss=True):
+
+def get_comment_item(response, post_result, block, uploadOss=True):
     item = ArticleCommentItem()
     item["domain_url"] = block["domain_url"]
     item["domain_id"] = block["domain_id"]
     item["domain_name"] = block["domain_name"]
     item["block_id"] = block["identification"]
     item["upload_oss"] = uploadOss
-    if source:
-        item["source_url"] = source["url"]
-        item["source_id"] = source["identification"]
-        item["source_name"] = source["name"]
-        item["upload_oss"] = source.get('upload_oss', False)
+    if post_result:
+        item["post_url"] = post_result["url"]
+        item["post_id"] = post_result["_id"]
+        item["upload_oss"] = post_result.get('upload_oss', False)
     if response:
         item["url"] = response.url
         item["url_md5"] = hashlib.md5(response.url.encode("utf-8")).hexdigest()
-    if parse:
-        content_regex = block.get('content_regex')
-        if content_regex and len(content_regex) > 0:
-            manual_parse(item, response, content_regex)
-        else:
-            auto_parse(item, response)
     return item
 
 
